delegatemanager — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

# delegatemanager

class `camelot.view.controls.delegates.delegatemanager.` `DelegateManager`(parent=None, **kwargs)

  Manages custom delegates, should not be used by the application developer

  `createEditor`(parent, option, index)

    Use a custom delegate createEditor method if it exists

  `insertColumnDelegate`(column, delegate)

    Inserts a custom column delegate

  `paint`(painter, option, index)

    Use a custom delegate paint method if it exists

  `removeColumnDelegate`(column)

    Removes custom column delegate

  `setEditorData`(editor, index)

    Use a custom delegate setEditorData method if it exists

  `setModelData`(editor, model, index)

    Use a custom delegate setModelData method if it exists

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

Comments
blog comments powered by Disqus